@@ -1,6 +1,6 @@
 package Geo::JSON;
 
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 # ABSTRACT: Perl OO interface for geojson
 
@@ -9,18 +9,15 @@ use warnings;
 use Carp;
 
 use JSON qw/ decode_json /;
+use List::Util qw/ first /;
+
+use constant GEOMETRY_OBJECTS => [
+    qw/ Point MultiPoint LineString MultiLineString Polygon MultiPolygon GeometryCollection /
+];
+use constant GEOJSON_OBJECTS => [    #
+    @{ +GEOMETRY_OBJECTS }, qw/ Feature FeatureCollection /
+];
 
-use Geo::JSON::CRS;
-use Geo::JSON::FeatureCollection;
-use Geo::JSON::Feature;
-use Geo::JSON::GeometryCollection;
-use Geo::JSON::Geometry;
-use Geo::JSON::LineString;
-use Geo::JSON::MultiLineString;
-use Geo::JSON::MultiPoint;
-use Geo::JSON::MultiPolygon;
-use Geo::JSON::Point;
-use Geo::JSON::Polygon;
 
 our $json = JSON->new->utf8->convert_blessed(1);
 
@@ -33,11 +30,23 @@ sub from_json {
     croak "from_json requires a JSON object (hashref)"
         unless ref $data eq 'HASH';
 
+    return $class->load($data);
+}
+
+
+sub load {
+    my ( $class, $data ) = @_;
+
     my $type = delete $data->{type}
         or croak "Invalid JSON data: no type specified";
 
     my $geo_json_class = 'Geo::JSON::' . $type;
 
+    croak "Invalid type '$type'"
+        unless first { $type eq $_ } @{ +GEOJSON_OBJECTS };
+
+    eval "require $geo_json_class";
+
     return $geo_json_class->new($data);
 }
 
@@ -66,13 +75,15 @@ Geo::JSON - Perl OO interface for geojson
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
     use Geo::JSON;
     
     my $obj = Geo::JSON->from_json( $json );
+    
+    $obj->to_json();
 
 =head1 DESCRIPTION
 
@@ -102,7 +113,7 @@ Determines the object the json will be turned into
 =item * C<position>
 
 Not explicitly named in the json, but an array of at least two numbers
-representing a location in x, y, z order. (Either Easting, Northing, Altitude
+representing a location in x, y, z order (either Easting, Northing, Altitude
 or Longitude, Latitude, Altitude as appropriate).
 
 Additional numbers may be present but ignored by this package for
@@ -120,7 +131,13 @@ number of axes and be in the same axis order.
 =item * C<bbox>
 
 Optional, defining a bounding box that the position(s) are contained by.
-FIXME define bbox
+
+The box is defined by a array of 2*n items, where n is the number of
+dimensions in a position. The items are the lowest value for an axis followed
+by the highest value for an axis, in the axis order used in the positions.
+
+The Co-ordinates Reference System for the bounding box is assumed to match
+that of the object.
 
 =item * C<crs>
 
@@ -129,7 +146,7 @@ L<Geo::JSON::CRS> for more details.
 
 =back
 
-=head1 OBJECTS
+=head1 GEOMETRY OBJECTS
 
 =over
 
@@ -164,11 +181,23 @@ An array of polygons
 
 An array of any of the above Geometry objects (as attribute C<geometries>)
 
+=back
+
+=head1 FEATURE OBJECTS
+
+=over
+
 =item * L<Geo::JSON::Feature>
 
 Any of the above objects (as attribute C<feature>), together with a data
 structure (as attruibute C<properties>)
 
+=back
+
+=head1 FEATURE COLLECTION OBJECTS
+
+=over
+
 =item * L<Geo::JSON::FeatureCollection>
 
 An array of Feature objects (as attribute C<features>)
@@ -183,6 +212,25 @@ An array of Feature objects (as attribute C<features>)
 
 Takes a geojson string, returns the object it represents.
 
+=head2 to_json
+
+    $obj->to_json();
+    $obj->to_json( $codec );
+
+Call on a Geo::JSON object. Returns the JSON that represents the object.
+
+Pass in an optional L<JSON> codec to modify the default behaviour of the JSON
+returned.
+
+=head2 load
+
+    my $obj = Geo::JSON->load( { type => 'Point', coordinates => ... } );
+
+Creates a Geo::JSON object from a hashref.
+
+This is used for coercion of attributes during object creation, and probably
+should not be called directly otherwise. 
+
 =head1 CLASS METHODS
 
 =head2 codec
