@@ -1,6 +1,6 @@
 package Geo::JSON::FeatureCollection;
 
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 # ABSTRACT: object representing a geojson FeatureCollection
 
@@ -11,6 +11,7 @@ use Carp;
 use Types::Standard qw/ ArrayRef HashRef /;
 
 use Geo::JSON::Types -types;
+use Geo::JSON::Utils;
 
 has features => (
     is       => 'ro',
@@ -21,6 +22,7 @@ has features => (
 
 sub all_positions {
     my $self = shift;
+
     return [ map { @{ $_->all_positions } } @{ $self->features } ];
 }
 
@@ -39,14 +41,18 @@ Geo::JSON::FeatureCollection - object representing a geojson FeatureCollection
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
     use Geo::JSON::FeatureCollection;
+    
+    # @feature_objects can be an array of Geo::JSON::Feature objects or
+    # hashrefs that define Geo::JSON::Feature objects.
     my $fcol = Geo::JSON::FeatureCollection->new({
-         features => \@features,
+         features => \@feature_objects,
     });
+    
     my $json = $fcol->to_json;
 
 =head1 DESCRIPTION
@@ -54,6 +60,18 @@ version 0.004
 A GeoJSON object with a features attribute of an arrayref of
 L<Geo::JSON::Feature> objects.
 
+See L<Geo::JSON> for more details.
+
+=head1 SEE ALSO
+
+=over
+
+=item *
+
+L<Geo::JSON::Feature>
+
+=back
+
 =head1 AUTHOR
 
 Michael Jemmeson <mjemmeson@cpan.org>
