@@ -1,11 +1,12 @@
 package Geo::JSON::MultiLineString;
 
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 # ABSTRACT: object representing a geojson MultiLineString
 
 use Moo;
-extends 'Geo::JSON::Geometry';
+extends 'Geo::JSON::Base';
+with 'Geo::JSON::Role::Geometry';
 
 use Geo::JSON::Types -types;
 
@@ -14,10 +15,7 @@ has '+coordinates' => ( isa => LineStrings );
 sub all_positions {
     my $self = shift;
 
-    return [
-        map { @{$_} }
-        map { @{$_} } @{ $self->coordinates }
-    ];
+    return [ map { @{$_} } @{ $self->coordinates } ];
 }
 
 
@@ -35,7 +33,7 @@ Geo::JSON::MultiLineString - object representing a geojson MultiLineString
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -51,6 +49,8 @@ version 0.004
 A GeoJSON object with a coordinates attribute of an arrayref of
 arrayrefs of positions.
 
+See L<Geo::JSON> for more details.
+
 =head1 AUTHOR
 
 Michael Jemmeson <mjemmeson@cpan.org>
