@@ -1,22 +1,17 @@
 package Geo::JSON::MultiPoint;
 
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 # ABSTRACT: object representing a geojson MultiPoint
 
 use Moo;
-extends 'Geo::JSON::Geometry';
+extends 'Geo::JSON::Base';
+with 'Geo::JSON::Role::Geometry';
 
 use Geo::JSON::Types -types;
 
 has '+coordinates' => ( isa => Positions );
 
-sub all_positions {
-    my $self = shift;
-
-    return [ map { @{$_} } @{ $self->coordinates } ];
-}
-
 
 1;
 
@@ -32,7 +27,7 @@ Geo::JSON::MultiPoint - object representing a geojson MultiPoint
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -49,6 +44,8 @@ version 0.004
 A GeoJSON object with a coordinates attribute consisting of an arrayref of
 positions.
 
+See L<Geo::JSON> for more details.
+
 =head1 AUTHOR
 
 Michael Jemmeson <mjemmeson@cpan.org>
